@@ -9,10 +9,10 @@
  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
  copies of the Software, and to permit persons to whom the Software is
  furnished to do so, subject to the following conditions:
- 
+
  The above copyright notice and this permission notice shall be included in
  all copies or substantial portions of the Software.
- 
+
  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
@@ -398,9 +398,9 @@ class fixed_matrix : public fixed_vector<T, Allocator>
           slices_iterator(_base::data(), max_channels, max_slices), max_slices);
 
       _channel_ptrs.reserve(max_channels);
-      for (const auto& channel: this->channels)
+      for (const auto channel: this->channels)
       {
-        _channel_ptrs.emplace_back(&*channel.begin());
+        _channel_ptrs.emplace_back(channel.begin());
       }
       assert(_channel_ptrs.size() == max_channels);
     }
@@ -597,7 +597,7 @@ fixed_matrix<T, Allocator>::set_channels(const Ch& ch)
 
   auto target = this->channels.begin();
 
-  for (const auto& i: ch)
+  for (const auto i: ch)
   {
     std::copy(i.begin(), i.end(), target->begin());
     ++target;
@@ -690,6 +690,3 @@ undistribute_list(const L1& source, L2& target, DataMember member, L3& garbage)
 }  // namespace apf
 
 #endif
-
-// Settings for Vim (http://www.vim.org/), please do not remove:
-// vim:softtabstop=2:shiftwidth=2:expandtab:textwidth=80:cindent
