@@ -9,10 +9,10 @@
  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
  copies of the Software, and to permit persons to whom the Software is
  furnished to do so, subject to the following conditions:
- 
+
  The above copyright notice and this permission notice shall be included in
  all copies or substantial portions of the Software.
- 
+
  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
@@ -239,7 +239,7 @@ TransformBase::prepare_partition(In first, In last, fft_node& partition) const
   return first + chunk;
 }
 
-/** Sort the FFT coefficients to be in proper place for the efficient 
+/** Sort the FFT coefficients to be in proper place for the efficient
  * multiplication of the spectra.
  **/
 void
@@ -336,7 +336,7 @@ void
 Input::add_block(In first)
 {
   In last = first;
-  std::advance(last, this->block_size());
+  std::advance(last, static_cast<std::ptrdiff_t>(this->block_size()));
 
   // rotate buffers (this->spectra.size() is always at least 2)
   this->spectra.move(--this->spectra.end(), this->spectra.begin());
@@ -839,6 +839,3 @@ void transform_nested(const Filter& in1, const Filter& in2, Filter& out
 }  // namespace apf
 
 #endif
-
-// Settings for Vim (http://www.vim.org/), please do not remove:
-// vim:softtabstop=2:shiftwidth=2:expandtab:textwidth=80:cindent
